# Recorder


## Records for MCMC are deprecated as Markov chains have no memory.
## TODO add recorder possibilities to something like a sampler.

Recorders are used to store properties of Markov chains to memory for every propose and occasionally write to the filesystem.
Recorders are implemented as mixins and can be combined freely.


